        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 24 <strong>control</strong><br>0,3,4,6,7,12,13,14,15,18,19,20,23,26,28,29,30,33,34,36,40,43,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>5,9,10,11,21,22,24,25,27,31,37,41,42,44,45,46,48';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>1,2,8,16,17,32,35,38,39,47';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 24 <strong>control</strong><br>0,3,4,6,7,12,13,14,15,18,19,20,23,26,28,29,30,33,34,36,40,43,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>5,9,10,11,21,22,24,25,27,31,37,41,42,44,45,46,48';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>1,2,8,16,17,32,35,38,39,47';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 24 <strong>control</strong><br>0,3,4,6,7,12,13,14,15,18,19,20,23,26,28,29,30,33,34,36,40,43,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>5,9,10,11,21,22,24,25,27,31,37,41,42,44,45,46,48';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>1,2,8,16,17,32,35,38,39,47';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 24 <strong>control</strong><br>0,3,4,6,7,12,13,14,15,18,19,20,23,26,28,29,30,33,34,36,40,43,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>5,9,10,11,21,22,24,25,27,31,37,41,42,44,45,46,48';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>1,2,8,16,17,32,35,38,39,47';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>1</strong> representante: <strong>26</strong> miembros: 24 <strong>control</strong><br>0,3,4,6,7,12,13,14,15,18,19,20,23,26,28,29,30,33,34,36,40,43,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>2</strong> representante: <strong>5</strong> miembros: 17 <br>5,9,10,11,21,22,24,25,27,31,37,41,42,44,45,46,48';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260502 a 00</strong> UTC HH+108 (rango:096-120)<br>grupo: <strong>3</strong> representante: <strong>17</strong> miembros: 10 <br>1,2,8,16,17,32,35,38,39,47';}
}
